/**
  ******************************************************************************
  * @file    wavetek_nRF.c
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    01-October-2014
  * @brief   This file provides set of firmware functions to manage Leds and
  *          push-button available on the wavetek board
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; COPYRIGHT(c) 2014 STMicroelectronics</center></h2>
  *
  * Redistribution and use in source and binary forms, with or without modification,
  * are permitted provided that the following conditions are met:
  *   1. Redistributions of source code must retain the above copyright notice,
  *      this list of conditions and the following disclaimer.
  *   2. Redistributions in binary form must reproduce the above copyright notice,
  *      this list of conditions and the following disclaimer in the documentation
  *      and/or other materials provided with the distribution.
  *   3. Neither the name of STMicroelectronics nor the names of its contributors
  *      may be used to endorse or promote products derived from this software
  *      without specific prior written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
  * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
  * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
  * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
  * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
  * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  ******************************************************************************
  */  
  
/* Includes ------------------------------------------------------------------*/
#include "wavetek_nRF_conf.h"

/* Private defines -----------------------------------------------------------*/
#define LED_number		3
#define BUTTON_number	3

/* Private variables ---------------------------------------------------------*/
GPIO_TypeDef* WAVETEK_NRF_LED_GPIO_PORT[LED_number] = {WAVETEK_NRF_LED1_GPIO_PORT, WAVETEK_NRF_LED2_GPIO_PORT, WAVETEK_NRF_LED3_GPIO_PORT};
const uint16_t WAVETEK_NRF_LED_GPIO_PIN[LED_number] = {WAVETEK_NRF_LED1_PIN, WAVETEK_NRF_LED2_PIN, WAVETEK_NRF_LED3_PIN};
GPIO_TypeDef* WAVETEK_NRF_BUTTON_GPIO_PORT[BUTTON_number] = {WAVETEK_NRF_BUTTON1_GPIO_PORT, WAVETEK_NRF_BUTTON2_GPIO_PORT, WAVETEK_NRF_BUTTON3_GPIO_PORT};
const uint16_t WAVETEK_NRF_BUTTON_GPIO[BUTTON_number] = {WAVETEK_NRF_BUTTON1_PIN, WAVETEK_NRF_BUTTON2_PIN, WAVETEK_NRF_BUTTON3_PIN};


/* Public functions ---------------------------------------------------------*/
/**
  * @brief  Function for initializing the nRF LEDs 1 2 3 .
  *
  * @note
  *
  * @param  None
  *
  * @retval None
  */
void wavetek_nRF_led_init(eWavetek_nRF_Led_TypeDef_t Led_id)
{
	GPIO_InitTypeDef GPIO_InitStructure;

	switch(Led_id)
	{
		case Wavetek_nRF_LED1_Id:
		case Wavetek_nRF_LED2_Id:
			__GPIOB_CLK_ENABLE();
			break;

		case Wavetek_nRF_LED3_Id:
			__GPIOA_CLK_ENABLE();
			break;

		default:
			break;
	}

	/*
	 * switch OFF The LEDs
	 */
	wavetek_nRF_led_off(Led_id);

  	GPIO_InitStructure.Mode = GPIO_MODE_OUTPUT_PP;
  	GPIO_InitStructure.Pull = GPIO_NOPULL;
  	GPIO_InitStructure.Speed = GPIO_SPEED_LOW;

  	GPIO_InitStructure.Pin = WAVETEK_NRF_LED_GPIO_PIN[Led_id];
  	HAL_GPIO_Init(WAVETEK_NRF_LED_GPIO_PORT[Led_id], &GPIO_InitStructure);

	return;
}

/**
  * @brief  Function for initializing the nRF51 buttons 1 2 3 .
  *
  * @note
  *
  * @param  None
  *
  * @retval None
  */
void wavetek_nRF_button_init(eWavetek_nRF_Button_TypeDef_t Button_id)
{
	GPIO_InitTypeDef GPIO_InitStructure;

	switch(Button_id)
	{
		case Wavetek_nRF_BUTTON1_Id:
		case Wavetek_nRF_BUTTON2_Id:
			__GPIOA_CLK_ENABLE();
			break;

		case Wavetek_nRF_BUTTON3_Id:
			__GPIOB_CLK_ENABLE();
			break;

		default:
			break;
	}

  	GPIO_InitStructure.Mode = GPIO_MODE_IT_FALLING;
  	GPIO_InitStructure.Pull = GPIO_PULLUP;
  	GPIO_InitStructure.Speed = GPIO_SPEED_LOW;
  	GPIO_InitStructure.Pin =  WAVETEK_NRF_BUTTON_GPIO[Button_id];
  	HAL_GPIO_Init(WAVETEK_NRF_BUTTON_GPIO_PORT[Button_id], &GPIO_InitStructure);

	switch(Button_id)
	{
		case Wavetek_nRF_BUTTON1_Id:
		  	HAL_NVIC_SetPriority(WAVETEK_NRF_BUTTON1_NVIC_VECTOR,		/**< Set NVIC priority */
		  						 WAVETEK_NRF_BUTTON1_IT_PREEMPTPRIORITY,
		  						 WAVETEK_NRF_BUTTON1_IT_SUBPRIORITY);
		  	HAL_NVIC_EnableIRQ(WAVETEK_NRF_BUTTON1_NVIC_VECTOR);		/**< Enable NVIC interrupt */
			break;

		case Wavetek_nRF_BUTTON2_Id:
		  	HAL_NVIC_SetPriority(WAVETEK_NRF_BUTTON2_NVIC_VECTOR,		/**< Set NVIC priority */
		  						 WAVETEK_NRF_BUTTON2_IT_PREEMPTPRIORITY,
		  						 WAVETEK_NRF_BUTTON2_IT_SUBPRIORITY);
		  	HAL_NVIC_EnableIRQ(WAVETEK_NRF_BUTTON2_NVIC_VECTOR);		/**< Enable NVIC interrupt */
			break;

		case Wavetek_nRF_BUTTON3_Id:
		  	HAL_NVIC_SetPriority(WAVETEK_NRF_BUTTON3_NVIC_VECTOR,		/**< Set NVIC priority */
		  						 WAVETEK_NRF_BUTTON3_IT_PREEMPTPRIORITY,
		  						 WAVETEK_NRF_BUTTON3_IT_SUBPRIORITY);
		  	HAL_NVIC_EnableIRQ(WAVETEK_NRF_BUTTON3_NVIC_VECTOR);		/**< Enable NVIC interrupt */
			break;

		default:
			break;
	}

	return;
}

void wavetek_nRF_led_off(eWavetek_nRF_Led_TypeDef_t Led_id)
{
	HAL_GPIO_WritePin(WAVETEK_NRF_LED_GPIO_PORT[Led_id], WAVETEK_NRF_LED_GPIO_PIN[Led_id], GPIO_PIN_SET);

	return;
}

void wavetek_nRF_led_on(eWavetek_nRF_Led_TypeDef_t Led_id)
{
	HAL_GPIO_WritePin(WAVETEK_NRF_LED_GPIO_PORT[Led_id], WAVETEK_NRF_LED_GPIO_PIN[Led_id], GPIO_PIN_RESET);

	return;
}

/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
