/**
  ******************************************************************************
  * @file    stm32L0xx_lppuart_driver_definition.h
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    01-October-2014
  * @brief   Header for stm32xx_lppuart.c module
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; COPYRIGHT(c) 2014 STMicroelectronics</center></h2>
  *
  * Redistribution and use in source and binary forms, with or without modification,
  * are permitted provided that the following conditions are met:
  *   1. Redistributions of source code must retain the above copyright notice,
  *      this list of conditions and the following disclaimer.
  *   2. Redistributions in binary form must reproduce the above copyright notice,
  *      this list of conditions and the following disclaimer in the documentation
  *      and/or other materials provided with the distribution.
  *   3. Neither the name of STMicroelectronics nor the names of its contributors
  *      may be used to endorse or promote products derived from this software
  *      without specific prior written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
  * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
  * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
  * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
  * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
  * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  ******************************************************************************
  */

/**
 * This file is expected to be used only by the UART driver implemented in the file stm32xx_lpp_uart.c.
 * It provided the mapping of the user selection to the UART driver
 * The user is not expected to modify this file
 */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __STM32L0XX_LPPUART_DRIVER_DEFINITION_H
#define __STM32L0XX_LPPUART_DRIVER_DEFINITION_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "stm32xx_lppuart_conf.h"

/* Exported types ------------------------------------------------------------*/
/* Exported defines --------------------------------------------------------*/

 /**
  *	UART mapping definition
  *
  *	The list of definition below is used to map the selected UART, the IO dedicated
  *	and the different resources used in the STM32 (Clock, DMA, etc...)
  */
#if (USART_SELECTED == BLE_ON_USART1)

#define USART_BLE						USART1
#define USART_NVIC_VECTOR				USART1_IRQn

 /**
  * DMA UART TX CHANNEL
  */
#if (USART_TX_DMA_CHANNEL_SELECTED == DMA1_CHANNEL4)

#define DMA_USART_TX_CHANNEL   		DMA1_Channel4
#define DMA_USART_TX_REQ		   		DMA_REQUEST_3

#elif (USART_TX_DMA_CHANNEL_SELECTED == DMA1_CHANNEL2)

#define DMA_USART_TX_CHANNEL   		DMA1_Channel2
#define DMA_USART_TX_REQ		   		DMA_REQUEST_3

#else
	#error USART_TX_DMA_CHANNEL_SELECTED NOT SUPPORTED
#endif

 /**
  * DMA UART RX CHANNEL
  */
#if (USART_RX_DMA_CHANNEL_SELECTED == DMA1_CHANNEL3)

#define DMA_USART_RX_CHANNEL			DMA1_Channel3
#define DMA_USART_RX_REQ	   			DMA_REQUEST_3
#define DMA_USART_RX_CHANNEL_FLAG		DMA_FLAG_TC3
#define DMA_USART_RX_NVIC_VECTOR		DMA1_Channel2_3_IRQn

#elif (USART_RX_DMA_CHANNEL_SELECTED == DMA1_CHANNEL5)

#define DMA_USART_RX_CHANNEL			DMA1_Channel5
#define DMA_USART_RX_REQ	   			DMA_REQUEST_3
#define DMA_USART_RX_CHANNEL_FLAG		DMA_FLAG_TC5
#define DMA_USART_RX_NVIC_VECTOR		DMA1_Channel4_5_6_7_IRQn

#else
	#error USART_RX_DMA_CHANNEL_SELECTED NOT SUPPORTED
#endif


 /**
  * UART TX PIN
  */
#if (USART_TX_PIN_SELECTED == PA9)

#define USART_TX_GPIO_AHB_CLK			RCC_IOPENR_GPIOAEN
#define USART_TX_GPIO_PORT         	GPIOA
#define USART_TX_PIN               	GPIO_PIN_9
#define USART_TX_PIN_SOURCE        	GPIO_PIN_POSITION_9
#define USART_TX_AF                	GPIO_AF4_USART1

#elif (USART_TX_PIN_SELECTED == PB6)

#define USART_TX_GPIO_AHB_CLK			RCC_IOPENR_GPIOBEN
#define USART_TX_GPIO_PORT         	GPIOB
#define USART_TX_PIN               	GPIO_PIN_6
#define USART_TX_PIN_SOURCE        	GPIO_PIN_POSITION_6
#define USART_TX_AF                	GPIO_AF0_USART1

#else
	#error USART_TX_PIN NOT SUPPORTED
#endif

 /**
  * UART RX PIN
  */
#if	(USART_RX_PIN_SELECTED == PA10)

#define USART_RX_GPIO_AHB_CLK			RCC_IOPENR_GPIOAEN
#define USART_RX_GPIO_PORT         	GPIOA
#define USART_RX_PIN               	GPIO_PIN_10
#define USART_RX_PIN_SOURCE        	GPIO_PIN_POSITION_10
#define USART_RX_AF                	GPIO_AF4_USART1

#elif (USART_RX_PIN_SELECTED == PB7)

#define USART_RX_GPIO_AHB_CLK      	RCC_IOPENR_GPIOBEN
#define USART_RX_GPIO_PORT         	GPIOB
#define USART_RX_PIN               	GPIO_PIN_7
#define USART_RX_PIN_SOURCE        	GPIO_PIN_POSITION_7
#define USART_RX_AF                	GPIO_AF0_USART1

#else
	#error USART_RX_PIN NOT SUPPORTED
#endif

 /**
  * UART RTS PIN
  */
#if (USART_RTS_PIN_SELECTED == PA12)

#define USART_WRTS_GPIO_AHB_CLK    	RCC_IOPENR_GPIOAEN
#define USART_WRTS_GPIO_PORT       	GPIOA
#define USART_WRTS_PIN             	GPIO_PIN_12
#define USART_WRTS_PIN_SOURCE      	GPIO_PIN_POSITION_12
#define USART_WRTS_AF              	GPIO_AF4_USART1

#else
	#error USART_RTS_PIN NOT SUPPORTED
#endif

 /**
  * UART CTS PIN
  */
#if	(USART_CTS_PIN_SELECTED == PA11)

#define USART_WCTS_GPIO_AHB_CLK    	RCC_IOPENR_GPIOAEN
#define USART_WCTS_GPIO_PORT       	GPIOA
#define USART_WCTS_PIN             	GPIO_PIN_11
#define USART_WCTS_PIN_SOURCE      	GPIO_PIN_POSITION_11
#define USART_WCTS_AF              	GPIO_AF4_USART1
#define USART_WCTS_SYSCFG_EXTI_PORT	SYSCFG_EXTI_PORTA
#define USART_WCTS_NVIC_VECTOR		 	EXTI4_15_IRQn

#else
	#error USART_CTS_PIN NOT SUPPORTED
#endif


#elif (USART_SELECTED == BLE_ON_USART2)

#define USART_BLE						USART2
#define USART_NVIC_VECTOR				USART2_IRQn

 /**
  * DMA UART TX CHANNEL
  */
#if (USART_TX_DMA_CHANNEL_SELECTED == DMA1_CHANNEL4)

#define DMA_USART_TX_CHANNEL   		DMA1_Channel4
#define DMA_USART_TX_REQ		   		DMA_REQUEST_4

#elif (USART_TX_DMA_CHANNEL_SELECTED == DMA1_CHANNEL7)

#define DMA_USART_TX_CHANNEL   		DMA1_Channel7
#define DMA_USART_TX_REQ		   		DMA_REQUEST_4

#else
	#error USART_TX_DMA_CHANNEL_SELECTED NOT SUPPORTED
#endif

 /**
  * DMA UART RX CHANNEL
  */
#if (USART_RX_DMA_CHANNEL_SELECTED == DMA1_CHANNEL5)

#define DMA_USART_RX_CHANNEL			DMA1_Channel5
#define DMA_USART_RX_REQ	   			DMA_REQUEST_4
#define DMA_USART_RX_CHANNEL_FLAG		DMA_FLAG_TC5
#define DMA_USART_RX_NVIC_VECTOR		DMA1_Channel4_5_6_7_IRQn

#elif (USART_RX_DMA_CHANNEL_SELECTED == DMA1_CHANNEL6)

#define DMA_USART_RX_CHANNEL			DMA1_Channel6
#define DMA_USART_RX_REQ	   			DMA_REQUEST_4
#define DMA_USART_RX_CHANNEL_FLAG		DMA_FLAG_TC6
#define DMA_USART_RX_NVIC_VECTOR		DMA1_Channel4_5_6_7_IRQn

#else
	#error USART_RX_DMA_CHANNEL_SELECTED NOT SUPPORTED
#endif

 /**
  * UART TX PIN
  */
#if (USART_TX_PIN_SELECTED == PA2)

#define USART_TX_GPIO_AHB_CLK    		RCC_IOPENR_GPIOAEN
#define USART_TX_GPIO_PORT       		GPIOA
#define USART_TX_PIN             		GPIO_PIN_2
#define USART_TX_PIN_SOURCE      		GPIO_PIN_POSITION_2
#define USART_TX_AF              		GPIO_AF4_USART2

#elif (USART_TX_PIN_SELECTED == PA14)

#define USART_TX_GPIO_AHB_CLK    		RCC_IOPENR_GPIOAEN
#define USART_TX_GPIO_PORT       		GPIOA
#define USART_TX_PIN             		GPIO_PIN_14
#define USART_TX_PIN_SOURCE      		GPIO_PIN_POSITION_14
#define USART_TX_AF              		GPIO_AF4_USART2

#else
	#error USART_TX_PIN NOT SUPPORTED
#endif

 /**
  * UART RX PIN
  */
#if (USART_RX_PIN_SELECTED == PA3)

#define USART_RX_GPIO_AHB_CLK    		RCC_IOPENR_GPIOAEN
#define USART_RX_GPIO_PORT       		GPIOA
#define USART_RX_PIN             		GPIO_PIN_3
#define USART_RX_PIN_SOURCE      		GPIO_PIN_POSITION_3
#define USART_RX_AF              		GPIO_AF4_USART2

#elif (USART_RX_PIN_SELECTED == PA15)

#define USART_RX_GPIO_AHB_CLK    		RCC_IOPENR_GPIOAEN
#define USART_RX_GPIO_PORT       		GPIOA
#define USART_RX_PIN             		GPIO_PIN_15
#define USART_RX_PIN_SOURCE      		GPIO_PIN_POSITION_15
#define USART_RX_AF              		GPIO_AF4_USART2

#else
	#error USART_RX_PIN NOT SUPPORTED
#endif

 /**
  * UART RTS PIN
  */
#if (USART_RTS_PIN_SELECTED == PA1)

#define USART_WRTS_GPIO_AHB_CLK    		RCC_IOPENR_GPIOAEN
#define USART_WRTS_GPIO_PORT       		GPIOA
#define USART_WRTS_PIN             		GPIO_PIN_1
#define USART_WRTS_PIN_SOURCE      		GPIO_PIN_POSITION_1
#define USART_WRTS_AF              		GPIO_AF4_USART2

#else
	#error USART_RTS_PIN NOT SUPPORTED
#endif

 /**
  * UART CTS PIN
  */
#if (USART_CTS_PIN_SELECTED == PA0)

#define USART_WCTS_GPIO_AHB_CLK    		RCC_IOPENR_GPIOAEN
#define USART_WCTS_GPIO_PORT       		GPIOA
#define USART_WCTS_PIN             		GPIO_PIN_0
#define USART_WCTS_PIN_SOURCE      		GPIO_PIN_POSITION_0
#define USART_WCTS_AF              		GPIO_AF4_USART2
#define USART_WCTS_SYSCFG_EXTI_PORT		SYSCFG_EXTI_PORTA
#define USART_WCTS_NVIC_VECTOR		 	EXTI0_1_IRQn

#else
	#error USART_CTS_PIN NOT SUPPORTED
#endif

#elif (USART_SELECTED == BLE_ON_LPUART)

#define USART_BLE						LPUART1
#define USART_NVIC_VECTOR				RNG_LPUART1_IRQn

 /**
  * DMA UART TX CHANNEL
  */
#if (USART_TX_DMA_CHANNEL_SELECTED == DMA1_CHANNEL2)

#define DMA_USART_TX_CHANNEL   		DMA1_Channel2
#define DMA_USART_TX_REQ		   		DMA_REQUEST_5

#elif (USART_TX_DMA_CHANNEL_SELECTED == DMA1_CHANNEL7)

#define DMA_USART_TX_CHANNEL   		DMA1_Channel7
#define DMA_USART_TX_REQ		   		DMA_REQUEST_5

#else
	#error USART_TX_DMA_CHANNEL_SELECTED NOT SUPPORTED
#endif

 /**
  * DMA UART RX CHANNEL
  */
#if (USART_RX_DMA_CHANNEL_SELECTED == DMA1_CHANNEL3)

#define DMA_USART_RX_CHANNEL			DMA1_Channel3
#define DMA_USART_RX_REQ	   			DMA_REQUEST_5
#define DMA_USART_RX_CHANNEL_FLAG		DMA_FLAG_TC3
#define DMA_USART_RX_NVIC_VECTOR		DMA1_Channel2_3_IRQn

#elif (USART_RX_DMA_CHANNEL_SELECTED == DMA1_CHANNEL6)

#define DMA_USART_RX_CHANNEL			DMA1_Channel6
#define DMA_USART_RX_REQ	   			DMA_REQUEST_5
#define DMA_USART_RX_CHANNEL_FLAG		DMA_FLAG_TC6
#define DMA_USART_RX_NVIC_VECTOR		DMA1_Channel4_5_6_7_IRQn

#else
	#error USART_RX_DMA_CHANNEL_SELECTED NOT SUPPORTED
#endif

 /**
  * UART TX PIN
  */
#if (USART_TX_PIN_SELECTED == PB10)

#define USART_TX_GPIO_AHB_CLK			RCC_IOPENR_GPIOBEN
#define USART_TX_GPIO_PORT          	GPIOB
#define USART_TX_PIN                	GPIO_PIN_10
#define USART_TX_PIN_SOURCE         	GPIO_PIN_POSITION_10
#define USART_TX_AF                 	GPIO_AF4_LPUART1

#elif (USART_TX_PIN_SELECTED == PC4)

#define USART_TX_GPIO_AHB_CLK			RCC_IOPENR_GPIOCEN
#define USART_TX_GPIO_PORT          	GPIOC
#define USART_TX_PIN                	GPIO_PIN_4
#define USART_TX_PIN_SOURCE         	GPIO_PIN_POSITION_4
#define USART_TX_AF                 	GPIO_AF2_LPUART1

#elif (USART_TX_PIN_SELECTED == PC10)

#define USART_TX_GPIO_AHB_CLK			RCC_IOPENR_GPIOCEN
#define USART_TX_GPIO_PORT          	GPIOC
#define USART_TX_PIN                	GPIO_PIN_10
#define USART_TX_PIN_SOURCE         	GPIO_PIN_POSITION_10
#define USART_TX_AF                 	GPIO_AF0_LPUART1

#else
	#error USART_TX_PIN NOT SUPPORTED
#endif

 /**
  * UART RX PIN
  */
#if (USART_RX_PIN_SELECTED == PB11)

#define USART_RX_GPIO_AHB_CLK       	RCC_IOPENR_GPIOBEN
#define USART_RX_GPIO_PORT          	GPIOB
#define USART_RX_PIN                	GPIO_PIN_11
#define USART_RX_PIN_SOURCE         	GPIO_PIN_POSITION_11
#define USART_RX_AF                 	GPIO_AF4_LPUART1

#elif (USART_RX_PIN_SELECTED == PC5)

#define USART_RX_GPIO_AHB_CLK       	RCC_IOPENR_GPIOCEN
#define USART_RX_GPIO_PORT          	GPIOC
#define USART_RX_PIN                	GPIO_PIN_5
#define USART_RX_PIN_SOURCE         	GPIO_PIN_POSITION_5
#define USART_RX_AF                 	GPIO_AF2_LPUART1

#elif (USART_RX_PIN_SELECTED == PC11)

#define USART_RX_GPIO_AHB_CLK       	RCC_IOPENR_GPIOCEN
#define USART_RX_GPIO_PORT          	GPIOC
#define USART_RX_PIN                	GPIO_PIN_11
#define USART_RX_PIN_SOURCE         	GPIO_PIN_POSITION_11
#define USART_RX_AF                 	GPIO_AF0_LPUART1

#else
	#error USART_RX_PIN NOT SUPPORTED
#endif

 /**
  * UART RTS PIN
  */
#if	(USART_RTS_PIN_SELECTED == PB14)

#define USART_WRTS_GPIO_AHB_CLK     	RCC_IOPENR_GPIOBEN
#define USART_WRTS_GPIO_PORT        	GPIOB
#define USART_WRTS_PIN              	GPIO_PIN_14
#define USART_WRTS_PIN_SOURCE       	GPIO_PIN_POSITION_14
#define USART_WRTS_AF               	GPIO_AF4_LPUART1

#elif (USART_RTS_PIN_SELECTED == PD2)

#define USART_WRTS_GPIO_AHB_CLK     	RCC_IOPENR_GPIODEN
#define USART_WRTS_GPIO_PORT        	GPIOD
#define USART_WRTS_PIN              	GPIO_PIN_2
#define USART_WRTS_PIN_SOURCE       	GPIO_PIN_POSITION_2
#define USART_WRTS_AF               	GPIO_AF0_LPUART1

#else
	#error USART_RTS_PIN NOT SUPPORTED
#endif

 /**
  * UART CTS PIN
  */
#if (USART_CTS_PIN_SELECTED == PA6)

#define USART_WCTS_GPIO_AHB_CLK    	RCC_IOPENR_GPIOAEN
#define USART_WCTS_GPIO_PORT       	GPIOA
#define USART_WCTS_PIN             	GPIO_PIN_6
#define USART_WCTS_PIN_SOURCE      	GPIO_PIN_POSITION_6
#define USART_WCTS_AF              	GPIO_AF4_LPUART1
#define USART_WCTS_SYSCFG_EXTI_PORT	SYSCFG_EXTI_PORTA
#define USART_WCTS_NVIC_VECTOR		EXTI4_15_IRQn

#elif (USART_CTS_PIN_SELECTED == PB13)

#define USART_WCTS_GPIO_AHB_CLK    	RCC_IOPENR_GPIOBEN
#define USART_WCTS_GPIO_PORT       	GPIOB
#define USART_WCTS_PIN             	GPIO_PIN_13
#define USART_WCTS_PIN_SOURCE      	GPIO_PIN_POSITION_13
#define USART_WCTS_AF              	GPIO_AF4_LPUART1
#define USART_WCTS_SYSCFG_EXTI_PORT	SYSCFG_EXTI_PORTB
#define USART_WCTS_NVIC_VECTOR		EXTI4_15_IRQn

#else
	#error USART_CTS_PIN NOT SUPPORTED
#endif

#else
	#error USART NOT SUPPORTED
#endif

#define USART_GPIO_AHB_CLK			(USART_TX_GPIO_AHB_CLK | USART_RX_GPIO_AHB_CLK | USART_WRTS_GPIO_AHB_CLK | USART_WCTS_GPIO_AHB_CLK)
#define USART_DMA_AHB_CLK 			RCC_AHBENR_DMA1EN

/* Exported constants --------------------------------------------------------*/
/* Exported macros -----------------------------------------------------------*/
/* Exported functions ------------------------------------------------------- */ 

#ifdef __cplusplus
}
#endif

#endif /*__STM32L0XX_LPPUART_DRIVER_DEFINITION_H */

/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
