/**
  ******************************************************************************
  * @file    stm32l0xx_lppuart_msp.h
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    01-October-2014
  * @brief   Header for stm32L0xx_lppuart_msp.c module
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; COPYRIGHT(c) 2014 STMicroelectronics</center></h2>
  *
  * Redistribution and use in source and binary forms, with or without modification,
  * are permitted provided that the following conditions are met:
  *   1. Redistributions of source code must retain the above copyright notice,
  *      this list of conditions and the following disclaimer.
  *   2. Redistributions in binary form must reproduce the above copyright notice,
  *      this list of conditions and the following disclaimer in the documentation
  *      and/or other materials provided with the distribution.
  *   3. Neither the name of STMicroelectronics nor the names of its contributors
  *      may be used to endorse or promote products derived from this software
  *      without specific prior written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
  * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
  * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
  * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
  * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
  * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __STM32L0XX_LPPUART_MSP_H
#define __STM32L0XX_LPPUART_MSP_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "stm32xx_lppuart_conf.h"

/* Exported types ------------------------------------------------------------*/
/* Exported constants --------------------------------------------------------*/
/* Exported macros -----------------------------------------------------------*/
 /**
  *	Macro to disable HW CTS flow control
  *
  *	The macro disables the CTS HW flow control in the UART block
  *	It shall be supported to use EXTI edge detector when the CTS HW flow is disabled
  */
 #define	LPPUART_MSP_DISABLE_UART_HW_CTS(__HANDLE__)		HAL_LPPUART_GPIO_Set_Mode(USART_WCTS_GPIO_PORT, USART_WCTS_PIN_SOURCE, GPIO_MODE_INPUT);

 /**
  *	Macro to enable HW CTS flow control
  *
  *	The macro is enables the CTS HW flow control in the UART block
  */
 #define	LPPUART_MSP_ENABLE_UART_HW_CTS(__HANDLE__)		HAL_LPPUART_GPIO_Set_Mode(USART_WCTS_GPIO_PORT, USART_WCTS_PIN_SOURCE, GPIO_MODE_AF_PP);

/* Exported functions ------------------------------------------------------- */
 void LPPUART_msp_dma_set_config(DMA_HandleTypeDef *hdma_tx, DMA_HandleTypeDef *hdma_rx);

#ifdef __cplusplus
}
#endif

#endif /*__STM32L0XX_LPPUART_MSP_H */

/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
