/**
  ******************************************************************************
  * @file    ble_uart.c
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    01-October-2014
  * @brief   Wrapper between BLE UART interface and low power protocol UART driver
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; COPYRIGHT(c) 2014 STMicroelectronics</center></h2>
  *
  * Redistribution and use in source and binary forms, with or without modification,
  * are permitted provided that the following conditions are met:
  *   1. Redistributions of source code must retain the above copyright notice,
  *      this list of conditions and the following disclaimer.
  *   2. Redistributions in binary form must reproduce the above copyright notice,
  *      this list of conditions and the following disclaimer in the documentation
  *      and/or other materials provided with the distribution.
  *   3. Neither the name of STMicroelectronics nor the names of its contributors
  *      may be used to endorse or promote products derived from this software
  *      without specific prior written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
  * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
  * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
  * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
  * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
  * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  ******************************************************************************
  */


/**
  * @note	This file contains the mapping of the BLE module UART interface to the low power protocol UART driver
  */

/* Includes ------------------------------------------------------------------*/
#include "nrf_error.h"
#include "app_uart_stream.h"
#include "stm32xx_lppuart_conf.h"

/* External variables --------------------------------------------------------*/
/* Private typedef -----------------------------------------------------------*/
/* Private defines -----------------------------------------------------------*/
/* Private macros ------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/
/* Public functions ----------------------------------------------------------*/

uint32_t app_uart_stream_open(const app_uart_stream_comm_params_t * p_comm_params)
 {
	 return NRF_SUCCESS;
 }

uint32_t app_uart_stream_evt_handler_reg(app_uart_stream_event_handler_t event_handler)
{
	 LPPUART_uart_open((pf_LPPUART_PhyDriverEvent_Handler_t)event_handler);

	 return NRF_SUCCESS;
}

 uint32_t app_uart_stream_close(void)
 {
	 return NRF_SUCCESS;
 }

 uint32_t app_uart_stream_write(const uint8_t * p_buffer, uint16_t length)
 {
	 LPPUART_send_data((uint8_t*)p_buffer, length);

	 return NRF_SUCCESS;
 }

 uint32_t app_uart_stream_rx_buffer_set(uint8_t * p_buffer, uint16_t num_of_bytes, bool header)
 {
	 LPPUART_receive_data(p_buffer);

	 return NRF_SUCCESS;
 }

/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
