/**
  ******************************************************************************
  * @file    app_conf.h
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    01-October-2014
  * @brief   Application configuration file
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; COPYRIGHT(c) 2014 STMicroelectronics</center></h2>
  *
  * Redistribution and use in source and binary forms, with or without modification,
  * are permitted provided that the following conditions are met:
  *   1. Redistributions of source code must retain the above copyright notice,
  *      this list of conditions and the following disclaimer.
  *   2. Redistributions in binary form must reproduce the above copyright notice,
  *      this list of conditions and the following disclaimer in the documentation
  *      and/or other materials provided with the distribution.
  *   3. Neither the name of STMicroelectronics nor the names of its contributors
  *      may be used to endorse or promote products derived from this software
  *      without specific prior written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
  * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
  * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
  * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
  * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
  * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __APP_CONF_H
#define __APP_CONF_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "stm32l0xx_hal.h"
#include "stm32xx_lppuart_conf.h"
#include "stm32xx_lpm_conf.h"
#include "stm32xx_timerserver_conf.h"
#include "stm32xx_nvm_conf.h"

/* Exported types ------------------------------------------------------------*/
/* Exported constants --------------------------------------------------------*/
/* Exported defines -----------------------------------------------------------*/

/*
 * SUPPORT HRS PROFILE
 */
#define	APP_HRS	1

/*
 * !!!!!  WARNING  !!!!!!
 * The HTS Profile is not supported in the current delivery
 * The compiler switch shall be kept to 0
 *
 * SUPPORT HTS PROFILE
 */
#define	APP_HTS	0

 /*
  * SUPPORT LED-BUTTON PROFILE (Only if (APP_HRS = 0) & (APP_HTS = 0) )
  */
 #define APP_LEDBUTTON 0

 /*
  * L2CAP THROUGHPUT TX TEST
  */
 #define APP_L2CAP_TX_TEST	0


/*
 * Select AHB Speed
 */
#define	HCLK_32MHZ	0

/*
 * JTAG support for debugging
 */
#define	JTAG_SUPPORTED	0

 /*
  * Lowest low power mode allow in the system
  */
#define	LOWEST_LOW_POWER_MODE	eLPM_Mode_LP_Stop

/* Exported macros -----------------------------------------------------------*/
 /* Compiler specific definition ------------------------------------------------------- */

 /*
  * Make sure the function (or variable) marked is part of the object file
  */
#if defined ( __CC_ARM )
#define USED __attribute__((used))
#elif defined ( __ICCARM__ )
#define USED __root
#elif defined ( __GNUC__ )
#define USED __attribute__((used))
#endif


#ifdef __cplusplus
}
#endif

#endif /*__APP_CONF_H */

/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
