/**
  ******************************************************************************
  * @file    msp_main.c
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    01-October-2014
  * @brief   This is the MCU dependent application implementation
  *
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; COPYRIGHT(c) 2014 STMicroelectronics</center></h2>
  *
  * Redistribution and use in source and binary forms, with or without modification,
  * are permitted provided that the following conditions are met:
  *   1. Redistributions of source code must retain the above copyright notice,
  *      this list of conditions and the following disclaimer.
  *   2. Redistributions in binary form must reproduce the above copyright notice,
  *      this list of conditions and the following disclaimer in the documentation
  *      and/or other materials provided with the distribution.
  *   3. Neither the name of STMicroelectronics nor the names of its contributors
  *      may be used to endorse or promote products derived from this software
  *      without specific prior written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
  * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
  * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
  * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
  * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
  * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  ******************************************************************************
  */

/* Includes ------------------------------------------------------------------*/
#include "app_conf.h"
#include "main.h"

/* Private typedef -----------------------------------------------------------*/
#if(APP_HTS == 1)
typedef struct
{
    int16_t TS_CAL_COLD;
    uint16_t reserved;
    int16_t TS_CAL_HOT;
} CALIB_TypeDef;
#endif

/* Private define ------------------------------------------------------------*/
#if(APP_HTS == 1)
#define FACTORY_CALIB_DATA	((CALIB_TypeDef *)0x1FF8007A)
#endif

/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
/* Public functions ---------------------------------------------------------*/

/**
  * @brief  Switch ON resources needed for BLE operation
  *
  * @note
  *
  * @param  None
  *
  * @retval None
  */
void UART_BLE_Init(void)
{
	/*
	 * Swich ON all IO blocks used by the UART
	 */

	if (USART_GPIO_AHB_CLK && RCC_IOPENR_GPIOAEN)
	{
		__GPIOA_CLK_ENABLE();
	}

	if (USART_GPIO_AHB_CLK && RCC_IOPENR_GPIOBEN)
	{
	__GPIOB_CLK_ENABLE();
	}

	if (USART_GPIO_AHB_CLK && RCC_IOPENR_GPIOCEN)
	{
	__GPIOC_CLK_ENABLE();
	}

	if (USART_GPIO_AHB_CLK && RCC_IOPENR_GPIODEN)
	{
	__GPIOD_CLK_ENABLE();
	}

	__DMA1_CLK_ENABLE();	/**< Switch ON DMA1 clock */

	__SYSCFG_CLK_ENABLE();	/**< Switch ON SYSCFG APB Clock */

#if (USART_SELECTED == BLE_ON_USART1)
	__USART1_CLK_ENABLE();	/**< Switch ON USART1 for BLE */
#elif (USART_SELECTED == BLE_ON_USART2)
	__USART2_CLK_ENABLE();	/**< Switch ON USART2 for BLE */
#elif (USART_SELECTED == BLE_ON_LPUART)
	__LPUART1_CLK_ENABLE();	/**< Switch ON LPUART1 for BLE */
#endif

	__PWR_CLK_ENABLE();		/**< Enable PWR clock */

	return;
}

/**
  * @brief  Configure the system clock
  *
  * @note	This API configures
  * 		- The system clock source
  * 		- The AHBCLK, APBCLK dividers
  * 		- The flash latency
  * 		- The PLL settings (when required)
  *
  * @param  None
  * @retval None
  */
void SystemClock_Config(void)
{
	RCC_OscInitTypeDef RCC_OscInitStruct;
	RCC_ClkInitTypeDef RCC_ClkInitStruct;

	/**
	 * Enable clock on PWR block
	 * This is used to setup registers when entering low power mode
	 */
	__PWR_CLK_ENABLE();

	/**
	 * Set voltage scaling range
	 */
	#if (HCLK_32MHZ == 1)
	__HAL_PWR_VOLTAGESCALING_CONFIG(PWR_REGULATOR_VOLTAGE_SCALE1);

	/**
	 *  Enable HSI oscillator and configure the PLL to reach the max system frequency (32MHz)
	 *  when using HSI oscillator as PLL clock source.
	 */
	RCC_OscInitStruct.OscillatorType = RCC_OSCILLATORTYPE_HSI;
	RCC_OscInitStruct.HSICalibrationValue = 0x10;
	RCC_OscInitStruct.HSIState = RCC_HSI_ON;
	RCC_OscInitStruct.PLL.PLLState = RCC_PLL_ON;
	RCC_OscInitStruct.PLL.PLLSource = RCC_PLLSOURCE_HSI;
	RCC_OscInitStruct.PLL.PLLMUL = RCC_PLLMUL_4;
	RCC_OscInitStruct.PLL.PLLDIV = RCC_PLLDIV_2;

	HAL_RCC_OscConfig(&RCC_OscInitStruct);

	/**
	 *  Select PLL as system clock source and configure the HCLK, PCLK1 and PCLK2 clocks dividers.
	 *  The SysTick 1 msec interrupt is required for the HAL process (Timeout management); by default
	 *  the configuration is done using the HAL_Init() API, and when the system clock configuration
	 *  is updated the SysTick configuration will be adjusted by the HAL_RCC_ClockConfig() API.
	 */
	RCC_ClkInitStruct.ClockType = (RCC_CLOCKTYPE_SYSCLK | RCC_CLOCKTYPE_HCLK | RCC_CLOCKTYPE_PCLK1 | RCC_CLOCKTYPE_PCLK2);
	RCC_ClkInitStruct.SYSCLKSource = RCC_SYSCLKSOURCE_PLLCLK;
	RCC_ClkInitStruct.AHBCLKDivider = RCC_SYSCLK_DIV1;
	RCC_ClkInitStruct.APB1CLKDivider = RCC_HCLK_DIV4;
	RCC_ClkInitStruct.APB2CLKDivider = RCC_HCLK_DIV4;

	HAL_RCC_ClockConfig(&RCC_ClkInitStruct, FLASH_LATENCY_1);

	#else
	/**
	* Reset value is Range 2
	*/

	/**
	 *  Enable HSI oscillator and configure the system at 8MHz
	 */
	RCC_OscInitStruct.OscillatorType = RCC_OSCILLATORTYPE_HSI;
	RCC_OscInitStruct.HSICalibrationValue = 0x10;
	RCC_OscInitStruct.HSIState = RCC_HSI_ON;
	RCC_OscInitStruct.PLL.PLLState = RCC_PLL_OFF;

	HAL_RCC_OscConfig(&RCC_OscInitStruct);

	/**
	 *  Configure the HCLK, PCLK1 and PCLK2 clocks dividers  to get 8Mhz.
	 *  The SysTick 1 msec interrupt is required for the HAL process (Timeout management); by default
	 *  the configuration is done using the HAL_Init() API, and when the system clock configuration
	 *  is updated the SysTick configuration will be adjusted by the HAL_RCC_ClockConfig() API.
	 */
	RCC_ClkInitStruct.ClockType = (RCC_CLOCKTYPE_SYSCLK | RCC_CLOCKTYPE_HCLK | RCC_CLOCKTYPE_PCLK1 | RCC_CLOCKTYPE_PCLK2);
	RCC_ClkInitStruct.SYSCLKSource = RCC_SYSCLKSOURCE_HSI;
	RCC_ClkInitStruct.AHBCLKDivider = RCC_SYSCLK_DIV2;
	RCC_ClkInitStruct.APB1CLKDivider = RCC_SYSCLK_DIV1;
	RCC_ClkInitStruct.APB2CLKDivider = RCC_SYSCLK_DIV1;

	HAL_RCC_ClockConfig(&RCC_ClkInitStruct, FLASH_LATENCY_0);

	#endif

	return;
}

/**
  * @brief  Configure the system for power optimization
  *
  * @note	This API configures the system to be ready for low power mode
  * 		- Unused GPIO in Analog mode
  * 		- Fast Wakeup
  * 		- Verefint disabled in low power mode
  * 		- FLASH in low power mode
  *
  * @param  None
  * @retval None
  */
void SystemPower_Config(void)
{
	GPIO_InitTypeDef GPIO_InitStructure;

	/**
	 * Disable FLASH in SLEEP Mode
	 */
	__HAL_FLASH_SLEEP_POWERDOWN_ENABLE();

	/**
	 * Enable Ultra low power and Fast wakeup as vrefint is not used in that project
	 */
	HAL_PWREx_EnableUltraLowPower();
	HAL_PWREx_EnableFastWakeUp();

	/*
	 * Select HSI as system clock source after Wake Up from Stop mode
	 */
	__HAL_RCC_WAKEUPSTOP_CLK_CONFIG(RCC_StopWakeUpClock_HSI);

	/*
	 * Disable all GPIOs clock in SLEEP mode
	 */
#if (JTAG_SUPPORTED == 0)
	__GPIOA_CLK_SLEEP_DISABLE();
#endif
	__GPIOB_CLK_SLEEP_DISABLE();
	__GPIOC_CLK_SLEEP_DISABLE();
	__GPIOD_CLK_SLEEP_DISABLE();
	__GPIOH_CLK_SLEEP_DISABLE();

	/*
	 * Enable GPIOs clock
	 */
	__GPIOA_CLK_ENABLE();
  	__GPIOB_CLK_ENABLE();
  	__GPIOC_CLK_ENABLE();
  	__GPIOD_CLK_ENABLE();
  	__GPIOH_CLK_ENABLE();

  	/*
  	 * Configure all GPIO port pins in Analog mode with no pull
  	 */
  	GPIO_InitStructure.Mode = GPIO_MODE_ANALOG;
  	GPIO_InitStructure.Pull = GPIO_NOPULL;
  	GPIO_InitStructure.Pin = GPIO_PIN_All;
  	HAL_GPIO_Init(GPIOB, &GPIO_InitStructure);
  	HAL_GPIO_Init(GPIOC, &GPIO_InitStructure);
  	HAL_GPIO_Init(GPIOD, &GPIO_InitStructure);
  	HAL_GPIO_Init(GPIOH, &GPIO_InitStructure);

  	#if (JTAG_SUPPORTED == 1)
	GPIO_InitStructure.Pin = (GPIO_PIN_All ^ (GPIO_PIN_13 | GPIO_PIN_14));
	#endif
  	HAL_GPIO_Init(GPIOA, &GPIO_InitStructure);

  	/*
  	 * Disable GPIOs clock
  	 */
  	__GPIOA_CLK_DISABLE();
  	__GPIOB_CLK_DISABLE();
  	__GPIOC_CLK_DISABLE();
  	__GPIOD_CLK_DISABLE();
  	__GPIOH_CLK_DISABLE();

  	return;
}

#if(APP_HTS == 1)
/**
  * @brief  Process the temperature acquired
  *
  * @note
  *
  * @param  None
  *
  * @retval None
  */
int16_t CalculateCalibratedTemperature(int16_t *pRawdata)
{
	int32_t	CalibData;

	CalibData = (130 - 30) * ((int32_t)(*pRawdata) - (int32_t)FACTORY_CALIB_DATA->TS_CAL_COLD) ;
	CalibData = CalibData / ((int32_t)FACTORY_CALIB_DATA->TS_CAL_HOT - (int32_t)FACTORY_CALIB_DATA->TS_CAL_COLD);
	CalibData = CalibData + 30;

	return (int16_t)CalibData;
}

/**
  * @brief  Configure the ADC for temperature measurement
  *
  * @note
  *
  * @param  None
  *
  * @retval None
  */
void InitADC_TemperatureSensor(ADC_HandleTypeDef* AdcHandle)
{
	ADC_ChannelConfTypeDef        sConfig;

	  /* ### - 1 - Initialize ADC peripheral #################################### */
	  /*
	   *  Instance                  = ADC1.
	   *  OversamplingMode          = Disabled
	   *  ClockPrescaler            = PCLK clock with no division.
	   *  LowPowerAutoOff           = Disabled (For this exemple continuous mode is enabled with software start)
	   *  LowPowerFrequencyMode     = Enabled (To be enabled only if ADC clock is lower than 2.8MHz)
	   *  LowPowerAutoWait          = Enabled (New conversion starts only when the previous conversion is completed)
	   *  Resolution                = 12 bit (increased to 16 bit with oversampler)
	   *  SamplingTime              = 7.5 cycles od ADC clock.
	   *  ScanDirection             = Upward
	   *  DataAlign                 = Right
	   *  ContinuousConvMode        = Enabled
	   *  DiscontinuousConvMode     = Enabled
	   *  ExternalTrigConvEdge      = None (Software start)
	   *  EOCSelection              = End Of Conversion event
	   *  DMAContinuousRequests     = ENABLE
	   */

	  AdcHandle->Instance = ADC1;

	  AdcHandle->Init.OversamplingMode      = DISABLE;

	  AdcHandle->Init.ClockPrescaler        = ADC_CLOCKPRESCALER_PCLK_DIV1;
	  AdcHandle->Init.LowPowerAutoOff       = DISABLE;
	  AdcHandle->Init.LowPowerFrequencyMode = DISABLE;
	  AdcHandle->Init.LowPowerAutoWait      = ENABLE;

	  AdcHandle->Init.Resolution            = ADC_RESOLUTION12b;
	  AdcHandle->Init.SamplingTime          = ADC_SAMPLETIME_41CYCLES_5;
	  AdcHandle->Init.ScanDirection         = ADC_SCAN_DIRECTION_UPWARD;
	  AdcHandle->Init.DataAlign             = ADC_DATAALIGN_RIGHT;
	  AdcHandle->Init.ContinuousConvMode    = DISABLE;
	  AdcHandle->Init.DiscontinuousConvMode = DISABLE;
	  AdcHandle->Init.ExternalTrigConvEdge  = ADC_EXTERNALTRIG_EDGE_NONE;
	  AdcHandle->Init.EOCSelection          = EOC_SINGLE_CONV;
	  AdcHandle->Init.DMAContinuousRequests = DISABLE;

	  /* Initialize ADC peripheral according to the passed parameters */
	  HAL_ADC_Init(AdcHandle);

	  /* ### - 2 - Start calibration ############################################ */
	  HAL_ADCEx_Calibration_Start(AdcHandle, ADC_SINGLE_ENDED);

	  /* ### - 3 - Channel configuration ######################################## */
	  /* Select Channel 0 to be converted */
	  sConfig.Channel = ADC_CHANNEL_TEMPSENSOR;
	  HAL_ADC_ConfigChannel(AdcHandle, &sConfig);
}

/**
* @brief  ADC MSP Init
* @param  hadc : ADC handle
* @retval None
*/
void HAL_ADC_MspInit(ADC_HandleTypeDef *localhadc)
{
  static DMA_HandleTypeDef         DmaHandle;

  /*##-1- Enable peripherals Clocks #################################*/
  /* ADC1 Periph clock enable */
  __ADC1_CLK_ENABLE();
  /* Enable DMA1 clock */
  __DMA1_CLK_ENABLE();

  /*##- 2- Configure DMA #####################################################*/

  /*********************** Configure DMA parameters ***************************/
  DmaHandle.Instance                 = DMA1_Channel1;
  DmaHandle.Init.Direction           = DMA_PERIPH_TO_MEMORY;
  DmaHandle.Init.PeriphInc           = DMA_PINC_DISABLE;
  DmaHandle.Init.MemInc              = DMA_MINC_ENABLE;
  DmaHandle.Init.PeriphDataAlignment = DMA_PDATAALIGN_HALFWORD;
  DmaHandle.Init.MemDataAlignment    = DMA_MDATAALIGN_HALFWORD;
  DmaHandle.Init.Mode                = DMA_CIRCULAR;
  DmaHandle.Init.Priority            = DMA_PRIORITY_MEDIUM;
  DmaHandle.Init.Request             = DMA_REQUEST_0;

  /* Deinitialize  & Initialize the DMA for new transfer */
  HAL_DMA_DeInit(&DmaHandle);
  HAL_DMA_Init(&DmaHandle);

  /* Associate the DMA handle */
  __HAL_LINKDMA(localhadc, DMA_Handle, DmaHandle);

  /* NVIC configuration for DMA Input data interrupt */
  HAL_NVIC_SetPriority(DMA1_Channel1_IRQn, 1, 0);
  HAL_NVIC_EnableIRQ(DMA1_Channel1_IRQn);
}

/**
  * @brief This function provides accurate delay (in milliseconds) based
  *        on variable incremented.
  * @note In the default implementation , SysTick timer is the source of time base.
  *       It is used to generate interrupts at regular time intervals where uwTick
  *       is incremented.
  * @note ThiS function is declared as __weak to be overwritten in case of other
  *       implementations in user file.
  * @note NOT USED IN THIS EXAMPLE
  * @param Delay: specifies the delay time length, in milliseconds.
  * @retval None
  */
void HAL_Delay(__IO uint32_t Delay)
{
	return;
}


#endif


/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
